@@ -1,6 +1,6 @@
 package Data::Format::Pretty::Console;
 BEGIN {
-  $Data::Format::Pretty::Console::VERSION = '0.07';
+  $Data::Format::Pretty::Console::VERSION = '0.08';
 }
 # ABSTRACT: Pretty-print data structure for console output
 
@@ -9,6 +9,7 @@ use 5.010;
 use strict;
 use warnings;
 
+use Log::Any '$log';
 use Scalar::Util qw(blessed);
 use Text::ASCIITable;
 use YAML::Any;
@@ -215,7 +216,8 @@ sub _format {
 
     } elsif ($struct eq 'aoh') {
 
-        my @cols = sort keys %{$struct_meta->{columns}};
+        my @cols = @{ _order_table_columns(
+            [keys %{$struct_meta->{columns}}], $opts) };
         if ($is_interactive) {
             my $t = Text::ASCIITable->new(); #{headingText => 'blah'}
             $t->setCols(@cols);
@@ -249,6 +251,47 @@ sub _format {
     }
 }
 
+sub _order_table_columns {
+    #$log->tracef('=> _order_table_columns(%s)', \@_);
+    my ($cols, $opts) = @_;
+
+    my $found; # whether we found an ordering in table_column_orders
+    my $tco = $opts->{table_column_orders};
+    my %orders; # colname => idx
+    if ($tco) {
+        die "table_column_orders should be an arrayref"
+            unless ref($tco) eq 'ARRAY';
+      CO:
+        for my $co (@$tco) {
+            die "table_column_orders elements must all be arrayrefs"
+                unless ref($co) eq 'ARRAY';
+            for (@$co) {
+                next CO unless $_ ~~ @$cols;
+            }
+
+            $found++;
+            for (my $i=0; $i<@$co; $i++) {
+                $orders{$co->[$i]} = $i;
+            }
+            $found++;
+            last CO;
+        }
+    }
+
+    my @ocols;
+    if ($found) {
+        @ocols = sort {
+            (defined($orders{$a}) && defined($orders{$b}) ?
+                 $orders{$a} <=> $orders{$b} : 0)
+                || $a cmp $b
+        } @$cols;
+    } else {
+        @ocols = sort @$cols;
+    }
+
+    \@ocols;
+}
+
 
 1;
 
@@ -261,7 +304,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -296,7 +339,7 @@ false):
  baz
  qux
 
-Hash, format_pretty({foo=>"data", bar=>"format", baz=>"pretty", qux=>"console"}):
+Hash, format_pretty({foo=>"data",bar=>"format",baz=>"pretty",qux=>"console"}):
 
  .---------------.
  | key | value   |
@@ -368,8 +411,10 @@ This module takes piping into consideration, and will output a simpler, more
 suitable format when your user pipes your program's output into some other
 program.
 
-Most of the time, you don't have to configure anything. But in the future some
-formatting settings will be tweakable.
+Most of the time, you don't have to configure anything, but some options are
+provided to tweak the output.
+
+This module uses L<Log::Any> for logging.
 
 =head1 FUNCTIONS
 
@@ -387,6 +432,23 @@ If set, will override interactive terminal detection (-t STDOUT). Simpler
 formatting will be done if terminal is non-interactive (e.g. when output is
 piped). Using this option will force simpler/full formatting.
 
+=item * table_column_orders => [[colname, colname], ...]
+
+Specify column orders when drawing a table. If a table has all the columns, then
+the column names will be ordered according to the specification. For example,
+when table_column_orders is [[qw/foo bar baz/]], this table's columns will not
+be reordered because it doesn't have all the mentioned columns:
+
+ |foo|quux|
+
+But this table will:
+
+ |apple|bar|baz|foo|quux|
+
+into:
+
+ |apple|foo|bar|baz|quux|
+
 =back
 
 =head1 SEE ALSO
